import os
import os.path
import re
import sys

from django import template

register = template.Library()

PATTERN = re.compile(r'page=(\d+)')

def _calc_page(value, func):
    t = PATTERN.search(value)
    if t is None:
        if '?' in value:
            return value + '&page=2'
        return value + '?&page=2'
    m = t.group()
    num = int(m.split('=')[1])
    return value.replace(m, '&page=%d' % func(num))

@register.filter(name='prev_page')
def prev_page(value):
    return _calc_page(value, lambda n: n-1)

@register.filter(name='next_page')
def next_page(value):
    return _calc_page(value, lambda n: n+1)

@register.filter(name='range')
def _range(min=1,max=5):
    return range(min,max+1)

@register.filter(name='photo_path')
def photo_path(value):
    t = value.split('/')
    if len(t) < 4:
        return ''
    return os.path.join(*t[-4:])
